@@ -20,8 +20,8 @@
 
 | **Language**     | **Package**        |
 |:-------------|-----------------|
-|![Python Logo](https://docs.aws.amazon.com/cdk/api/latest/img/python32.png) Python|`aws_solutions_constructs.aws_sns_lambda`|
-|![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-sns-lambda`|
+|![Python Logo](https://docs.aws.amazon.com/cdk/api/latest/img/python32.png) Python|`aws_solutions_constructs.aws_sqs_lambda`|
+|![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-sqs-lambda`|
 |![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.sqslambda`|
 
 This AWS Solutions Construct implements an Amazon SQS queue connected to an AWS Lambda function.
@@ -32,7 +32,6 @@ Here is a minimal deployable pattern definition:
 const { SqsToLambda } = require('@aws-solutions-constructs/aws-sqs-lambda');
 
 new SqsToLambda(stack, 'SqsToLambdaPattern', {
-    deployLambda: true,
     lambdaFunctionProps: {
         runtime: lambda.Runtime.NODEJS_10_X,
         handler: 'index.handler',
@@ -58,9 +57,9 @@ new SqsToLambda(scope: Construct, id: string, props: SqsToLambdaProps);
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|deployLambda|`boolean`|Whether to create a new Lambda function or use an existing Lambda function.|
-|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|An optional, existing Lambda function.|
-|lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|Optional user-provided props to override the default props for the Lambda function.|
+|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.|
+|lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|User provided props to override the default props for the Lambda function.|
+|existingQueueObj?|[`sqs.Queue`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-sqs.Queue.html)|An optional, existing SQS queue to be used instead of the default queue. If an existing queue is provided, the `queueProps` property will be ignored.|
 |queueProps?|[`sqs.QueueProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-sqs.QueueProps.html)|Optional user-provided props to override the default props for the SQS queue.|
 |deadLetterQueueProps?|[`sqs.QueueProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-sqs.QueueProps.html)|Optional user-provided props to override the default props for the dead letter SQS queue.|
 |deployDeadLetterQueue?|`boolean`|Whether to create a secondary queue to be used as a dead letter queue. Defaults to true.|
@@ -129,10 +128,10 @@ class SqsToLambda(
         scope: aws_cdk.core.Construct,
         id: str,
         *,
-        deploy_lambda: bool,
         dead_letter_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
         deploy_dead_letter_queue: typing.Optional[bool] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+        existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
         queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
@@ -140,11 +139,11 @@ class SqsToLambda(
         """
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
-        :param deploy_lambda: Whether to create a new Lambda function or use an existing Lambda function. If set to false, you must provide an existing function for the ``existingLambdaObj`` property. Default: - true
         :param dead_letter_queue_props: Optional user provided properties for the dead letter queue. Default: - Default props are used
         :param deploy_dead_letter_queue: Whether to deploy a secondary queue to be used as a dead letter queue. Default: - true.
-        :param existing_lambda_obj: Existing instance of Lambda Function object. If ``deploy`` is set to false only then this property is required Default: - None
-        :param lambda_function_props: Optional user provided properties to override the default properties for the Lambda function. If ``deploy`` is set to true only then this property is required. Default: - Default properties are used.
+        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
+        :param existing_queue_obj: Existing instance of SQS queue object, if this is set then queueProps is ignored. Default: - Default props are used
+        :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default properties are used.
         :param max_receive_count: The number of times a message can be unsuccessfully dequeued before being moved to the dead-letter queue. Default: - required field if deployDeadLetterQueue=true.
         :param queue_props: Optional user provided properties. Default: - Default props are used
 
@@ -156,10 +155,10 @@ class SqsToLambda(
         :summary:: Constructs a new instance of the SqsToLambda class.
         """
         props = SqsToLambdaProps(
-            deploy_lambda=deploy_lambda,
             dead_letter_queue_props=dead_letter_queue_props,
             deploy_dead_letter_queue=deploy_dead_letter_queue,
             existing_lambda_obj=existing_lambda_obj,
+            existing_queue_obj=existing_queue_obj,
             lambda_function_props=lambda_function_props,
             max_receive_count=max_receive_count,
             queue_props=queue_props,
@@ -187,10 +186,10 @@ class SqsToLambda(
     jsii_type="@aws-solutions-constructs/aws-sqs-lambda.SqsToLambdaProps",
     jsii_struct_bases=[],
     name_mapping={
-        "deploy_lambda": "deployLambda",
         "dead_letter_queue_props": "deadLetterQueueProps",
         "deploy_dead_letter_queue": "deployDeadLetterQueue",
         "existing_lambda_obj": "existingLambdaObj",
+        "existing_queue_obj": "existingQueueObj",
         "lambda_function_props": "lambdaFunctionProps",
         "max_receive_count": "maxReceiveCount",
         "queue_props": "queueProps",
@@ -200,20 +199,20 @@ class SqsToLambdaProps:
     def __init__(
         self,
         *,
-        deploy_lambda: bool,
         dead_letter_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
         deploy_dead_letter_queue: typing.Optional[bool] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
+        existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
         queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
     ) -> None:
         """
-        :param deploy_lambda: Whether to create a new Lambda function or use an existing Lambda function. If set to false, you must provide an existing function for the ``existingLambdaObj`` property. Default: - true
         :param dead_letter_queue_props: Optional user provided properties for the dead letter queue. Default: - Default props are used
         :param deploy_dead_letter_queue: Whether to deploy a secondary queue to be used as a dead letter queue. Default: - true.
-        :param existing_lambda_obj: Existing instance of Lambda Function object. If ``deploy`` is set to false only then this property is required Default: - None
-        :param lambda_function_props: Optional user provided properties to override the default properties for the Lambda function. If ``deploy`` is set to true only then this property is required. Default: - Default properties are used.
+        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
+        :param existing_queue_obj: Existing instance of SQS queue object, if this is set then queueProps is ignored. Default: - Default props are used
+        :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default properties are used.
         :param max_receive_count: The number of times a message can be unsuccessfully dequeued before being moved to the dead-letter queue. Default: - required field if deployDeadLetterQueue=true.
         :param queue_props: Optional user provided properties. Default: - Default props are used
 
@@ -230,15 +229,15 @@ class SqsToLambdaProps:
             )
         if isinstance(queue_props, dict):
             queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
-        self._values = {
-            "deploy_lambda": deploy_lambda,
-        }
+        self._values = {}
         if dead_letter_queue_props is not None:
             self._values["dead_letter_queue_props"] = dead_letter_queue_props
         if deploy_dead_letter_queue is not None:
             self._values["deploy_dead_letter_queue"] = deploy_dead_letter_queue
         if existing_lambda_obj is not None:
             self._values["existing_lambda_obj"] = existing_lambda_obj
+        if existing_queue_obj is not None:
+            self._values["existing_queue_obj"] = existing_queue_obj
         if lambda_function_props is not None:
             self._values["lambda_function_props"] = lambda_function_props
         if max_receive_count is not None:
@@ -246,17 +245,6 @@ class SqsToLambdaProps:
         if queue_props is not None:
             self._values["queue_props"] = queue_props
 
-    @builtins.property
-    def deploy_lambda(self) -> bool:
-        """Whether to create a new Lambda function or use an existing Lambda function.
-
-        If set to false, you must provide an existing function for the ``existingLambdaObj`` property.
-
-        default
-        :default: - true
-        """
-        return self._values.get("deploy_lambda")
-
     @builtins.property
     def dead_letter_queue_props(self) -> typing.Optional[aws_cdk.aws_sqs.QueueProps]:
         """Optional user provided properties for the dead letter queue.
@@ -277,22 +265,27 @@ class SqsToLambdaProps:
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
-        """Existing instance of Lambda Function object.
-
-        If ``deploy`` is set to false only then this property is required
+        """Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
 
         default
         :default: - None
         """
         return self._values.get("existing_lambda_obj")
 
+    @builtins.property
+    def existing_queue_obj(self) -> typing.Optional[aws_cdk.aws_sqs.Queue]:
+        """Existing instance of SQS queue object, if this is set then queueProps is ignored.
+
+        default
+        :default: - Default props are used
+        """
+        return self._values.get("existing_queue_obj")
+
     @builtins.property
     def lambda_function_props(
         self,
     ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
-        """Optional user provided properties to override the default properties for the Lambda function.
-
-        If ``deploy`` is set to true only then this property is required.
+        """User provided props to override the default props for the Lambda function.
 
         default
         :default: - Default properties are used.
